@@ -259,7 +259,7 @@ void testing_herk_batched(const Arguments& arg)
     rocblas_init_matrix(
         hA, arg, rocblas_client_alpha_sets_nan, rocblas_client_general_matrix, true, true);
     rocblas_init_matrix(
-        hC, arg, rocblas_client_beta_sets_nan, rocblas_client_hermitian_matrix, false, true);
+        hC, arg, rocblas_client_beta_sets_nan, rocblas_client_general_matrix, false, true);
 
     hC_gold.copy_from(hC);
 
